static char const G_line[] =
{
  '#',' ','C','o','n','f','i','g','u','r','a','t','i','o','n',' ','f','i','l','e',' ','f','o','r',' ','d','i','r','c','o','l','o','r','s',',',' ','a',' ','u','t','i','l','i','t','y',' ','t','o',' ','h','e','l','p',' ','y','o','u',' ','s','e','t',' ','t','h','e',0,
  '#',' ','L','S','_','C','O','L','O','R','S',' ','e','n','v','i','r','o','n','m','e','n','t',' ','v','a','r','i','a','b','l','e',' ','u','s','e','d',' ','b','y',' ','G','N','U',' ','l','s',' ','w','i','t','h',' ','t','h','e',' ','-','-','c','o','l','o','r',' ','o','p','t','i','o','n','.',0,
  '#',' ','C','o','p','y','r','i','g','h','t',' ','(','C',')',' ','1','9','9','6',',',' ','1','9','9','9','-','2','0','0','8',0,
  '#',' ','F','r','e','e',' ','S','o','f','t','w','a','r','e',' ','F','o','u','n','d','a','t','i','o','n',',',' ','I','n','c','.',0,
  '#',' ','C','o','p','y','i','n','g',' ','a','n','d',' ','d','i','s','t','r','i','b','u','t','i','o','n',' ','o','f',' ','t','h','i','s',' ','f','i','l','e',',',' ','w','i','t','h',' ','o','r',' ','w','i','t','h','o','u','t',' ','m','o','d','i','f','i','c','a','t','i','o','n',',',0,
  '#',' ','a','r','e',' ','p','e','r','m','i','t','t','e','d',' ','p','r','o','v','i','d','e','d',' ','t','h','e',' ','c','o','p','y','r','i','g','h','t',' ','n','o','t','i','c','e',' ','a','n','d',' ','t','h','i','s',' ','n','o','t','i','c','e',' ','a','r','e',' ','p','r','e','s','e','r','v','e','d','.',0,
  '#',' ','T','h','e',' ','k','e','y','w','o','r','d','s',' ','C','O','L','O','R',',',' ','O','P','T','I','O','N','S',',',' ','a','n','d',' ','E','I','G','H','T','B','I','T',' ','(','h','o','n','o','r','e','d',' ','b','y',' ','t','h','e',0,
  '#',' ','s','l','a','c','k','w','a','r','e',' ','v','e','r','s','i','o','n',' ','o','f',' ','d','i','r','c','o','l','o','r','s',')',' ','a','r','e',' ','r','e','c','o','g','n','i','z','e','d',' ','b','u','t',' ','i','g','n','o','r','e','d','.',0,
  '#',' ','B','e','l','o','w',',',' ','t','h','e','r','e',' ','s','h','o','u','l','d',' ','b','e',' ','o','n','e',' ','T','E','R','M',' ','e','n','t','r','y',' ','f','o','r',' ','e','a','c','h',' ','t','e','r','m','t','y','p','e',' ','t','h','a','t',' ','i','s',' ','c','o','l','o','r','i','z','a','b','l','e',0,
  'T','E','R','M',' ','E','t','e','r','m',0,
  'T','E','R','M',' ','a','n','s','i',0,
  'T','E','R','M',' ','c','o','l','o','r','-','x','t','e','r','m',0,
  'T','E','R','M',' ','c','o','n','1','3','2','x','2','5',0,
  'T','E','R','M',' ','c','o','n','1','3','2','x','3','0',0,
  'T','E','R','M',' ','c','o','n','1','3','2','x','4','3',0,
  'T','E','R','M',' ','c','o','n','1','3','2','x','6','0',0,
  'T','E','R','M',' ','c','o','n','8','0','x','2','5',0,
  'T','E','R','M',' ','c','o','n','8','0','x','2','8',0,
  'T','E','R','M',' ','c','o','n','8','0','x','3','0',0,
  'T','E','R','M',' ','c','o','n','8','0','x','4','3',0,
  'T','E','R','M',' ','c','o','n','8','0','x','5','0',0,
  'T','E','R','M',' ','c','o','n','8','0','x','6','0',0,
  'T','E','R','M',' ','c','o','n','s','2','5',0,
  'T','E','R','M',' ','c','o','n','s','o','l','e',0,
  'T','E','R','M',' ','c','y','g','w','i','n',0,
  'T','E','R','M',' ','d','t','t','e','r','m',0,
  'T','E','R','M',' ','e','t','e','r','m','-','c','o','l','o','r',0,
  'T','E','R','M',' ','g','n','o','m','e',0,
  'T','E','R','M',' ','g','n','o','m','e','-','2','5','6','c','o','l','o','r',0,
  'T','E','R','M',' ','j','f','b','t','e','r','m',0,
  'T','E','R','M',' ','k','o','n','s','o','l','e',0,
  'T','E','R','M',' ','k','t','e','r','m',0,
  'T','E','R','M',' ','l','i','n','u','x',0,
  'T','E','R','M',' ','l','i','n','u','x','-','c',0,
  'T','E','R','M',' ','m','a','c','h','-','c','o','l','o','r',0,
  'T','E','R','M',' ','m','l','t','e','r','m',0,
  'T','E','R','M',' ','p','u','t','t','y',0,
  'T','E','R','M',' ','r','x','v','t',0,
  'T','E','R','M',' ','r','x','v','t','-','c','y','g','w','i','n',0,
  'T','E','R','M',' ','r','x','v','t','-','c','y','g','w','i','n','-','n','a','t','i','v','e',0,
  'T','E','R','M',' ','r','x','v','t','-','u','n','i','c','o','d','e',0,
  'T','E','R','M',' ','s','c','r','e','e','n',0,
  'T','E','R','M',' ','s','c','r','e','e','n','-','2','5','6','c','o','l','o','r',0,
  'T','E','R','M',' ','s','c','r','e','e','n','-','b','c','e',0,
  'T','E','R','M',' ','s','c','r','e','e','n','-','w',0,
  'T','E','R','M',' ','s','c','r','e','e','n','.','l','i','n','u','x',0,
  'T','E','R','M',' ','v','t','1','0','0',0,
  'T','E','R','M',' ','x','t','e','r','m',0,
  'T','E','R','M',' ','x','t','e','r','m','-','1','6','c','o','l','o','r',0,
  'T','E','R','M',' ','x','t','e','r','m','-','2','5','6','c','o','l','o','r',0,
  'T','E','R','M',' ','x','t','e','r','m','-','8','8','c','o','l','o','r',0,
  'T','E','R','M',' ','x','t','e','r','m','-','c','o','l','o','r',0,
  'T','E','R','M',' ','x','t','e','r','m','-','d','e','b','i','a','n',0,
  '#',' ','B','e','l','o','w',' ','a','r','e',' ','t','h','e',' ','c','o','l','o','r',' ','i','n','i','t',' ','s','t','r','i','n','g','s',' ','f','o','r',' ','t','h','e',' ','b','a','s','i','c',' ','f','i','l','e',' ','t','y','p','e','s','.',' ','A',' ','c','o','l','o','r',' ','i','n','i','t',0,
  '#',' ','s','t','r','i','n','g',' ','c','o','n','s','i','s','t','s',' ','o','f',' ','o','n','e',' ','o','r',' ','m','o','r','e',' ','o','f',' ','t','h','e',' ','f','o','l','l','o','w','i','n','g',' ','n','u','m','e','r','i','c',' ','c','o','d','e','s',':',0,
  '#',' ','A','t','t','r','i','b','u','t','e',' ','c','o','d','e','s',':',0,
  '#',' ','0','0','=','n','o','n','e',' ','0','1','=','b','o','l','d',' ','0','4','=','u','n','d','e','r','s','c','o','r','e',' ','0','5','=','b','l','i','n','k',' ','0','7','=','r','e','v','e','r','s','e',' ','0','8','=','c','o','n','c','e','a','l','e','d',0,
  '#',' ','T','e','x','t',' ','c','o','l','o','r',' ','c','o','d','e','s',':',0,
  '#',' ','3','0','=','b','l','a','c','k',' ','3','1','=','r','e','d',' ','3','2','=','g','r','e','e','n',' ','3','3','=','y','e','l','l','o','w',' ','3','4','=','b','l','u','e',' ','3','5','=','m','a','g','e','n','t','a',' ','3','6','=','c','y','a','n',' ','3','7','=','w','h','i','t','e',0,
  '#',' ','B','a','c','k','g','r','o','u','n','d',' ','c','o','l','o','r',' ','c','o','d','e','s',':',0,
  '#',' ','4','0','=','b','l','a','c','k',' ','4','1','=','r','e','d',' ','4','2','=','g','r','e','e','n',' ','4','3','=','y','e','l','l','o','w',' ','4','4','=','b','l','u','e',' ','4','5','=','m','a','g','e','n','t','a',' ','4','6','=','c','y','a','n',' ','4','7','=','w','h','i','t','e',0,
  '#','N','O','R','M','A','L',' ','0','0',' ','#',' ','n','o',' ','c','o','l','o','r',' ','c','o','d','e',' ','a','t',' ','a','l','l',0,
  '#','F','I','L','E',' ','0','0',' ','#',' ','r','e','g','u','l','a','r',' ','f','i','l','e',':',' ','u','s','e',' ','n','o',' ','c','o','l','o','r',' ','a','t',' ','a','l','l',0,
  'R','E','S','E','T',' ','0',' ','#',' ','r','e','s','e','t',' ','t','o',' ','"','n','o','r','m','a','l','"',' ','c','o','l','o','r',0,
  'D','I','R',' ','0','1',';','3','4',' ','#',' ','d','i','r','e','c','t','o','r','y',0,
  'L','I','N','K',' ','0','1',';','3','6',' ','#',' ','s','y','m','b','o','l','i','c',' ','l','i','n','k','.',' ','(','I','f',' ','y','o','u',' ','s','e','t',' ','t','h','i','s',' ','t','o',' ','\'','t','a','r','g','e','t','\'',' ','i','n','s','t','e','a','d',' ','o','f',' ','a',0,
  ' ','#',' ','n','u','m','e','r','i','c','a','l',' ','v','a','l','u','e',',',' ','t','h','e',' ','c','o','l','o','r',' ','i','s',' ','a','s',' ','f','o','r',' ','t','h','e',' ','f','i','l','e',' ','p','o','i','n','t','e','d',' ','t','o','.',')',0,
  'F','I','F','O',' ','4','0',';','3','3',' ','#',' ','p','i','p','e',0,
  'S','O','C','K',' ','0','1',';','3','5',' ','#',' ','s','o','c','k','e','t',0,
  'D','O','O','R',' ','0','1',';','3','5',' ','#',' ','d','o','o','r',0,
  'B','L','K',' ','4','0',';','3','3',';','0','1',' ','#',' ','b','l','o','c','k',' ','d','e','v','i','c','e',' ','d','r','i','v','e','r',0,
  'C','H','R',' ','4','0',';','3','3',';','0','1',' ','#',' ','c','h','a','r','a','c','t','e','r',' ','d','e','v','i','c','e',' ','d','r','i','v','e','r',0,
  'O','R','P','H','A','N',' ','4','0',';','3','1',';','0','1',' ','#',' ','s','y','m','l','i','n','k',' ','t','o',' ','n','o','n','e','x','i','s','t','e','n','t',' ','f','i','l','e',',',' ','o','r',' ','n','o','n','-','s','t','a','t','\'','a','b','l','e',' ','f','i','l','e',0,
  'S','E','T','U','I','D',' ','3','7',';','4','1',' ','#',' ','f','i','l','e',' ','t','h','a','t',' ','i','s',' ','s','e','t','u','i','d',' ','(','u','+','s',')',0,
  'S','E','T','G','I','D',' ','3','0',';','4','3',' ','#',' ','f','i','l','e',' ','t','h','a','t',' ','i','s',' ','s','e','t','g','i','d',' ','(','g','+','s',')',0,
  'C','A','P','A','B','I','L','I','T','Y',' ','3','0',';','4','1',' ','#',' ','f','i','l','e',' ','w','i','t','h',' ','c','a','p','a','b','i','l','i','t','y',0,
  'S','T','I','C','K','Y','_','O','T','H','E','R','_','W','R','I','T','A','B','L','E',' ','3','0',';','4','2',' ','#',' ','d','i','r',' ','t','h','a','t',' ','i','s',' ','s','t','i','c','k','y',' ','a','n','d',' ','o','t','h','e','r','-','w','r','i','t','a','b','l','e',' ','(','+','t',',','o','+','w',')',0,
  'O','T','H','E','R','_','W','R','I','T','A','B','L','E',' ','3','4',';','4','2',' ','#',' ','d','i','r',' ','t','h','a','t',' ','i','s',' ','o','t','h','e','r','-','w','r','i','t','a','b','l','e',' ','(','o','+','w',')',' ','a','n','d',' ','n','o','t',' ','s','t','i','c','k','y',0,
  'S','T','I','C','K','Y',' ','3','7',';','4','4',' ','#',' ','d','i','r',' ','w','i','t','h',' ','t','h','e',' ','s','t','i','c','k','y',' ','b','i','t',' ','s','e','t',' ','(','+','t',')',' ','a','n','d',' ','n','o','t',' ','o','t','h','e','r','-','w','r','i','t','a','b','l','e',0,
  '#',' ','T','h','i','s',' ','i','s',' ','f','o','r',' ','f','i','l','e','s',' ','w','i','t','h',' ','e','x','e','c','u','t','e',' ','p','e','r','m','i','s','s','i','o','n',':',0,
  'E','X','E','C',' ','0','1',';','3','2',0,
  '#',' ','L','i','s','t',' ','a','n','y',' ','f','i','l','e',' ','e','x','t','e','n','s','i','o','n','s',' ','l','i','k','e',' ','\'','.','g','z','\'',' ','o','r',' ','\'','.','t','a','r','\'',' ','t','h','a','t',' ','y','o','u',' ','w','o','u','l','d',' ','l','i','k','e',' ','l','s',0,
  '#',' ','t','o',' ','c','o','l','o','r','i','z','e',' ','b','e','l','o','w','.',' ','P','u','t',' ','t','h','e',' ','e','x','t','e','n','s','i','o','n',',',' ','a',' ','s','p','a','c','e',',',' ','a','n','d',' ','t','h','e',' ','c','o','l','o','r',' ','i','n','i','t',' ','s','t','r','i','n','g','.',0,
  '#',' ','(','a','n','d',' ','a','n','y',' ','c','o','m','m','e','n','t','s',' ','y','o','u',' ','w','a','n','t',' ','t','o',' ','a','d','d',' ','a','f','t','e','r',' ','a',' ','\'','#','\'',')',0,
  '#',' ','I','f',' ','y','o','u',' ','u','s','e',' ','D','O','S','-','s','t','y','l','e',' ','s','u','f','f','i','x','e','s',',',' ','y','o','u',' ','m','a','y',' ','w','a','n','t',' ','t','o',' ','u','n','c','o','m','m','e','n','t',' ','t','h','e',' ','f','o','l','l','o','w','i','n','g',':',0,
  '#','.','c','m','d',' ','0','1',';','3','2',' ','#',' ','e','x','e','c','u','t','a','b','l','e','s',' ','(','b','r','i','g','h','t',' ','g','r','e','e','n',')',0,
  '#','.','e','x','e',' ','0','1',';','3','2',0,
  '#','.','c','o','m',' ','0','1',';','3','2',0,
  '#','.','b','t','m',' ','0','1',';','3','2',0,
  '#','.','b','a','t',' ','0','1',';','3','2',0,
  '#',' ','O','r',' ','i','f',' ','y','o','u',' ','w','a','n','t',' ','t','o',' ','c','o','l','o','r','i','z','e',' ','s','c','r','i','p','t','s',' ','e','v','e','n',' ','i','f',' ','t','h','e','y',' ','d','o',' ','n','o','t',' ','h','a','v','e',' ','t','h','e',0,
  '#',' ','e','x','e','c','u','t','a','b','l','e',' ','b','i','t',' ','a','c','t','u','a','l','l','y',' ','s','e','t','.',0,
  '#','.','s','h',' ','0','1',';','3','2',0,
  '#','.','c','s','h',' ','0','1',';','3','2',0,
  ' ','#',' ','a','r','c','h','i','v','e','s',' ','o','r',' ','c','o','m','p','r','e','s','s','e','d',' ','(','b','r','i','g','h','t',' ','r','e','d',')',0,
  '.','t','a','r',' ','0','1',';','3','1',0,
  '.','t','g','z',' ','0','1',';','3','1',0,
  '.','a','r','j',' ','0','1',';','3','1',0,
  '.','t','a','z',' ','0','1',';','3','1',0,
  '.','l','z','h',' ','0','1',';','3','1',0,
  '.','l','z','m','a',' ','0','1',';','3','1',0,
  '.','z','i','p',' ','0','1',';','3','1',0,
  '.','z',' ','0','1',';','3','1',0,
  '.','Z',' ','0','1',';','3','1',0,
  '.','d','z',' ','0','1',';','3','1',0,
  '.','g','z',' ','0','1',';','3','1',0,
  '.','b','z','2',' ','0','1',';','3','1',0,
  '.','b','z',' ','0','1',';','3','1',0,
  '.','t','b','z','2',' ','0','1',';','3','1',0,
  '.','t','z',' ','0','1',';','3','1',0,
  '.','d','e','b',' ','0','1',';','3','1',0,
  '.','r','p','m',' ','0','1',';','3','1',0,
  '.','j','a','r',' ','0','1',';','3','1',0,
  '.','r','a','r',' ','0','1',';','3','1',0,
  '.','a','c','e',' ','0','1',';','3','1',0,
  '.','z','o','o',' ','0','1',';','3','1',0,
  '.','c','p','i','o',' ','0','1',';','3','1',0,
  '.','7','z',' ','0','1',';','3','1',0,
  '.','r','z',' ','0','1',';','3','1',0,
  '#',' ','i','m','a','g','e',' ','f','o','r','m','a','t','s',0,
  '.','j','p','g',' ','0','1',';','3','5',0,
  '.','j','p','e','g',' ','0','1',';','3','5',0,
  '.','g','i','f',' ','0','1',';','3','5',0,
  '.','b','m','p',' ','0','1',';','3','5',0,
  '.','p','b','m',' ','0','1',';','3','5',0,
  '.','p','g','m',' ','0','1',';','3','5',0,
  '.','p','p','m',' ','0','1',';','3','5',0,
  '.','t','g','a',' ','0','1',';','3','5',0,
  '.','x','b','m',' ','0','1',';','3','5',0,
  '.','x','p','m',' ','0','1',';','3','5',0,
  '.','t','i','f',' ','0','1',';','3','5',0,
  '.','t','i','f','f',' ','0','1',';','3','5',0,
  '.','p','n','g',' ','0','1',';','3','5',0,
  '.','s','v','g',' ','0','1',';','3','5',0,
  '.','s','v','g','z',' ','0','1',';','3','5',0,
  '.','m','n','g',' ','0','1',';','3','5',0,
  '.','p','c','x',' ','0','1',';','3','5',0,
  '.','m','o','v',' ','0','1',';','3','5',0,
  '.','m','p','g',' ','0','1',';','3','5',0,
  '.','m','p','e','g',' ','0','1',';','3','5',0,
  '.','m','2','v',' ','0','1',';','3','5',0,
  '.','m','k','v',' ','0','1',';','3','5',0,
  '.','o','g','m',' ','0','1',';','3','5',0,
  '.','m','p','4',' ','0','1',';','3','5',0,
  '.','m','4','v',' ','0','1',';','3','5',0,
  '.','m','p','4','v',' ','0','1',';','3','5',0,
  '.','v','o','b',' ','0','1',';','3','5',0,
  '.','q','t',' ','0','1',';','3','5',0,
  '.','n','u','v',' ','0','1',';','3','5',0,
  '.','w','m','v',' ','0','1',';','3','5',0,
  '.','a','s','f',' ','0','1',';','3','5',0,
  '.','r','m',' ','0','1',';','3','5',0,
  '.','r','m','v','b',' ','0','1',';','3','5',0,
  '.','f','l','c',' ','0','1',';','3','5',0,
  '.','a','v','i',' ','0','1',';','3','5',0,
  '.','f','l','i',' ','0','1',';','3','5',0,
  '.','f','l','v',' ','0','1',';','3','5',0,
  '.','g','l',' ','0','1',';','3','5',0,
  '.','d','l',' ','0','1',';','3','5',0,
  '.','x','c','f',' ','0','1',';','3','5',0,
  '.','x','w','d',' ','0','1',';','3','5',0,
  '.','y','u','v',' ','0','1',';','3','5',0,
  '#',' ','h','t','t','p',':','/','/','w','i','k','i','.','x','i','p','h','.','o','r','g','/','i','n','d','e','x','.','p','h','p','/','M','I','M','E','_','T','y','p','e','s','_','a','n','d','_','F','i','l','e','_','E','x','t','e','n','s','i','o','n','s',0,
  '.','a','x','v',' ','0','1',';','3','5',0,
  '.','a','n','x',' ','0','1',';','3','5',0,
  '.','o','g','v',' ','0','1',';','3','5',0,
  '.','o','g','x',' ','0','1',';','3','5',0,
  '#',' ','a','u','d','i','o',' ','f','o','r','m','a','t','s',0,
  '.','a','a','c',' ','0','0',';','3','6',0,
  '.','a','u',' ','0','0',';','3','6',0,
  '.','f','l','a','c',' ','0','0',';','3','6',0,
  '.','m','i','d',' ','0','0',';','3','6',0,
  '.','m','i','d','i',' ','0','0',';','3','6',0,
  '.','m','k','a',' ','0','0',';','3','6',0,
  '.','m','p','3',' ','0','0',';','3','6',0,
  '.','m','p','c',' ','0','0',';','3','6',0,
  '.','o','g','g',' ','0','0',';','3','6',0,
  '.','r','a',' ','0','0',';','3','6',0,
  '.','w','a','v',' ','0','0',';','3','6',0,
  '#',' ','h','t','t','p',':','/','/','w','i','k','i','.','x','i','p','h','.','o','r','g','/','i','n','d','e','x','.','p','h','p','/','M','I','M','E','_','T','y','p','e','s','_','a','n','d','_','F','i','l','e','_','E','x','t','e','n','s','i','o','n','s',0,
  '.','a','x','a',' ','0','0',';','3','6',0,
  '.','o','g','a',' ','0','0',';','3','6',0,
  '.','s','p','x',' ','0','0',';','3','6',0,
  '.','x','s','p','f',' ','0','0',';','3','6',0,
};
